@@ -6,16 +6,14 @@
 #' @export
 #' @family low-level API functions
 process_response <- function(res) {
-
   if (httr::status_code(res) == 204) {
     return(TRUE)
   }
 
   if (httr::status_code(res) >= 200 && httr::status_code(res) < 300) {
     return(res %>%
-             stop_for_content_type() %>%
-             httr::content(as = "parsed", type = "application/json")
-    )
+      stop_for_content_type() %>%
+      httr::content(as = "parsed", type = "application/json"))
   }
 
   type <- res$headers$`Content-type`
@@ -29,9 +27,11 @@ process_response <- function(res) {
   errors <- out$errors[[1]]
   msg <- glue("HTTP error [{out$code}] {out$message}")
   details <- glue_data(errors, "  * {names(errors)}: {errors}")
-  err_msg <- collapse(c(msg, details), sep = "\n")
-  cl <- c("googledrive_error", paste0("http_error_", out$code),
-          "error", "condition")
+  err_msg <- glue_collapse(c(msg, details), sep = "\n")
+  cl <- c(
+    "googledrive_error", paste0("http_error_", out$code),
+    "error", "condition"
+  )
   cond <- structure(list(message = err_msg), class = cl)
   stop(cond)
 }
@@ -40,8 +40,9 @@ stop_for_content_type <- function(response,
                                   expected = "application/json; charset=UTF-8") {
   actual <- response$headers$`Content-Type`
   if (actual != expected) {
-    stop_glue("\n\nExpected content-type:\n  * {expected}\n",
-          "Actual content-type:\n  * {actual}"
+    stop_glue(
+      "\n\nExpected content-type:\n  * {expected}\n",
+      "Actual content-type:\n  * {actual}"
     )
   }
   response
